ClientHelpCommand class final

Represents the 'CLIENT HELP' command.

Inheritance

Constructors

ClientHelpCommand()

Properties

commandParts List<String>
The command and its arguments, to be implemented by each subclass.
no setteroverride
encoded List<int>
latefinalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(dynamic data) String
The parser for the response, to be implemented by each subclass.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited