HGetCommand class final

Represents the 'HGET key field' command.

Redis Command:

HGET user:1 name

Redis Reply (Example):

$5
Alice

Dart Result (from parse method): String? resolving to 'Alice' or null

Parameters:

  • key: The key of the hash.
  • field: The field to retrieve.
Inheritance
Mixed-in types

Constructors

HGetCommand(String key, String field)

Properties

commandParts List<String>
The command and its arguments, to be implemented by each subclass.
no setteroverride
encoded List<int>
latefinalinherited
field String
final
hashCode int
The hash code for this object.
no setterinherited
key String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyPrefix(String prefix) ValkeyCommand<String?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(dynamic data) String?
The parser for the response, to be implemented by each subclass.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited