IncrByCommand class final

Represents the 'INCRBY key increment' command. Increments the number stored at key by increment.

Redis Command:

INCRBY mycounter 5

Redis Reply (Example):

:15

Dart Result (from parse method): int resolving to 15

Parameters:

  • key: The key to increment.
  • increment: The amount to increment by.
Inheritance
Mixed-in types

Constructors

IncrByCommand(String key, int increment)

Properties

commandParts List<String>
The command and its arguments, to be implemented by each subclass.
no setteroverride
encoded List<int>
latefinalinherited
hashCode int
The hash code for this object.
no setterinherited
increment int
final
key String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyPrefix(String prefix) ValkeyCommand<int>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(dynamic data) int
The parser for the response, to be implemented by each subclass.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited