InsecureConnection class

Implemented types

Constructors

InsecureConnection({required BaseRespCodec respDecoder, String host = '127.00.1', int port = 6379, Duration connectionTimeout = const Duration(seconds: 10), Future<void> onConnected()?, void onData(dynamic data)?, void onDone()?, void onError(Object error)?, int maxReconnectAttempts = 5, bool disableNagle = true})

Properties

connectionTimeout Duration
finalinherited
disableNagle bool
finalinherited
hashCode int
The hash code for this object.
no setterinherited
host String
finalinherited
isConnected bool
no setterinherited
maxReconnectAttempts int
finalinherited
onConnected Future<void> Function()?
finalinherited
onData → void Function(dynamic data)?
finalinherited
onDone → void Function()?
finalinherited
onError → void Function(Object error)?
finalinherited
password String?
getter/setter pairinherited
port int
finalinherited
respDecoder BaseRespCodec
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
testSocket Socket?
no setterinherited
username String?
getter/setter pairinherited

Methods

close() Future<void>
Closes the connection and releases all resources.
inherited
connect({String? username, String? password}) Future<void>
Initiates the connection to the server.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
performSocketConnection() Future<Socket>
The template method that subclasses must implement to provide a connected socket.
send(List<int> data) → void
Sends a command (encoded as a list of bytes) to the server.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited