PersistCommand class final

Represents the 'PERSIST key' command. Removes the expiration from a key.

Redis Command:

PERSIST mykey

Redis Reply (Example):

:1

Dart Result (from parse method): bool resolving to true (TTL removed) or false (key does not exist or no TTL)

Inheritance
Mixed-in types

Constructors

PersistCommand(String key)

Properties

commandParts List<String>
The command and its arguments, to be implemented by each subclass.
no setteroverride
encoded List<int>
latefinalinherited
hashCode int
The hash code for this object.
no setterinherited
key String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyPrefix(String prefix) ValkeyCommand<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(dynamic data) bool
The parser for the response, to be implemented by each subclass.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited