RPopLPushCommand class final
Represents the 'RPOPLPUSH source destination' command. Atomically removes the last element from source, and pushes it to the head of destination.
Redis Command:
RPOPLPUSH mylist myotherlist
Redis Reply (Example):
$5
itemX
Dart Result (from parse method):
String? resolving to 'itemX' or null
- Inheritance
-
- Object
- Command<
String?> - ValkeyCommand<
String?> - RPopLPushCommand
- Mixed-in types
Constructors
- RPopLPushCommand(String source, String destination)
Properties
-
commandParts
→ List<
String> -
The command and its arguments, to be implemented by each subclass.
no setteroverride
- destination → String
-
final
-
encoded
→ List<
int> -
latefinalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → String
-
final
Methods
-
applyPrefix(
String prefix) → ValkeyCommand< String?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
dynamic data) → String? -
The parser for the response, to be implemented by each subclass.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited