SUnionStoreCommand class final
Represents the 'SUNIONSTORE destination key key ...' command.
Stores the members of the union of all the given sets in destination.
Redis Command:
SUNIONSTORE newset set1 set2
Redis Reply (Example):
:3
Dart Result (from parse method):
int resolving to 3 (number of elements in the resulting set)
- Inheritance
-
- Object
- Command<
int> - ValkeyCommand<
int> - SUnionStoreCommand
- Mixed-in types
Constructors
-
SUnionStoreCommand(String destination, List<
String> keys)
Properties
-
commandParts
→ List<
String> -
The command and its arguments, to be implemented by each subclass.
no setteroverride
- destination → String
-
final
-
encoded
→ List<
int> -
latefinalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
keys
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
applyPrefix(
String prefix) → ValkeyCommand< int> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
dynamic data) → int -
The parser for the response, to be implemented by each subclass.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited