ZRevRankCommand class final

Represents the 'ZREVRANK key member' command. Returns the rank of member in the sorted set at key, with the scores ordered from high to low.

Redis Command:

ZREVRANK myzset member2

Redis Reply (Example):

:0

Dart Result (from parse method): int? resolving to 0 or null

Inheritance
Mixed-in types

Constructors

ZRevRankCommand(String key, String member)

Properties

commandParts List<String>
The command and its arguments, to be implemented by each subclass.
no setteroverride
encoded List<int>
latefinalinherited
hashCode int
The hash code for this object.
no setterinherited
key String
final
member String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyPrefix(String prefix) ValkeyCommand<int?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(dynamic data) int?
The parser for the response, to be implemented by each subclass.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited