HValsCommand class final
Represents the 'HVALS key' command. Returns all values in the hash stored at key.
Redis Command:
HVALS user:1
Redis Reply (Example):
*2
$5
Alice
$2
30
Dart Result (from parse method):
List<String> resolving to ['Alice', '30']
Parameters:
- key: The key of the hash.
- Inheritance
- Mixed-in types
Constructors
- HValsCommand(String key)
Properties
-
commandParts
→ List<
String> -
The command and its arguments, to be implemented by each subclass.
no setteroverride
-
encoded
→ List<
int> -
latefinalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
applyPrefix(
String prefix) → ValkeyCommand< List< String> > -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
dynamic data) → List< String> -
The parser for the response, to be implemented by each subclass.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited