RenameCommand class final
Represents the 'RENAME key newkey' command. Renames a key.
Redis Command:
RENAME oldkey newkey
Redis Reply (Example):
+OK
Dart Result (from parse method):
String resolving to 'OK'
- Inheritance
-
- Object
- Command<
bool> - ValkeyCommand<
bool> - RenameCommand
- Mixed-in types
Constructors
- RenameCommand(String key, String newKey)
Properties
-
commandParts
→ List<
String> -
The command and its arguments, to be implemented by each subclass.
no setteroverride
-
encoded
→ List<
int> -
latefinalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
final
- newKey → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
applyPrefix(
String prefix) → ValkeyCommand< bool> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
dynamic data) → bool -
The parser for the response, to be implemented by each subclass.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited